@@ -1,4 +1,3 @@
-from .db import Db
-from .deezer import Deezer, Lyrics
 from .official_charts import Scraper
+from .deezer import Deezer
 from .tag import Tag
