@@ -1,7 +1,8 @@
 import base64
-import requests
 from typing import Dict
 
+import requests
+
 
 class Spotify:
     def __init__(self, client_id: str, client_secret: str) -> None:
@@ -13,9 +14,7 @@ class Spotify:
         data = {"grant_type": "client_credentials"}
         auth_code = base64.b64encode(f"{client_id}:{client_secret}".encode()).decode()
         headers = {"Authorization": f"Basic {auth_code}"}
-        resp = requests.post(
-            "https://accounts.spotify.com/api/token", data=data, headers=headers
-        )
+        resp = requests.post("https://accounts.spotify.com/api/token", data=data, headers=headers)
 
         auth_token = resp.json()["access_token"]
 
